@@ -873,3 +873,7 @@ Tellico::Data::ID Collection::getID() {
   static ID id = 0;
   return ++id;
 }
+
+Data::FieldPtr Collection::primaryImageField() const {
+  return m_imageFields.isEmpty() ? Data::FieldPtr() : fieldByName(m_imageFields.front()->name());
+}
