@@ -25,7 +25,7 @@
 #include "bookcollection.h"
 #include "../entrycomparison.h"
 
-#include <klocale.h>
+#include <KLocalizedString>
 
 namespace {
   static const char* book_general = I18N_NOOP("General");
@@ -48,7 +48,7 @@ Tellico::Data::FieldList BookCollection::defaultFields() {
   FieldList list;
   FieldPtr field;
 
-  list.append(createDefaultField(TitleField));
+  list.append(Field::createDefaultField(Field::TitleField));
 
   field = new Field(QLatin1String("subtitle"), i18n("Subtitle"));
   field->setCategory(i18n(book_general));
@@ -182,33 +182,32 @@ Tellico::Data::FieldList BookCollection::defaultFields() {
   field = new Field(QLatin1String("cover"), i18n("Front Cover"), Field::Image);
   list.append(field);
 
-  field = new Field(QLatin1String("comments"), i18n("Comments"), Field::Para);
-  field->setCategory(i18n(book_personal));
+  field = new Field(QLatin1String("plot"), i18n("Plot Summary"), Field::Para);
   list.append(field);
 
-  list.append(createDefaultField(IDField));
-  list.append(createDefaultField(CreatedDateField));
-  list.append(createDefaultField(ModifiedDateField));
+  field = new Field(QLatin1String("comments"), i18n("Comments"), Field::Para);
+  list.append(field);
+
+  list.append(Field::createDefaultField(Field::IDField));
+  list.append(Field::createDefaultField(Field::CreatedDateField));
+  list.append(Field::createDefaultField(Field::ModifiedDateField));
 
   return list;
 }
 
 int BookCollection::sameEntry(Tellico::Data::EntryPtr entry1_, Tellico::Data::EntryPtr entry2_) const {
+  if(!entry1_ || !entry2_) {
+    return 0;
+  }
   // equal isbn's or lccn's are easy, give it a weight of 100
   if(EntryComparison::score(entry1_, entry2_, QLatin1String("isbn"), this) > 0 ||
      EntryComparison::score(entry1_, entry2_, QLatin1String("lccn"), this) > 0) {
     return 100; // good match
   }
   int res = 3*EntryComparison::score(entry1_, entry2_, QLatin1String("title"), this);
-//  if(res == 0) {
-//    myDebug() << "different titles for " << entry1_->title() << " vs. "
-//              << entry2_->title();
-//  }
   res += 2*EntryComparison::score(entry1_, entry2_, QLatin1String("author"), this);
   res += EntryComparison::score(entry1_, entry2_, QLatin1String("cr_year"), this);
   res += EntryComparison::score(entry1_, entry2_, QLatin1String("pub_year"), this);
   res += EntryComparison::score(entry1_, entry2_, QLatin1String("binding"), this);
   return res;
 }
-
-#include "bookcollection.moc"
