@@ -48,7 +48,7 @@ Tellico::Data::FieldList ComicBookCollection::defaultFields() {
   FieldList list;
   FieldPtr field;
 
-  list.append(createDefaultField(TitleField));
+  list.append(Field::createDefaultField(Field::TitleField));
 
   field = new Field(QLatin1String("subtitle"), i18n("Subtitle"));
   field->setCategory(i18n(comic_general));
@@ -159,13 +159,15 @@ Tellico::Data::FieldList ComicBookCollection::defaultFields() {
   field = new Field(QLatin1String("cover"), i18n("Front Cover"), Field::Image);
   list.append(field);
 
-  field = new Field(QLatin1String("comments"), i18n("Comments"), Field::Para);
-  field->setCategory(i18n(comic_personal));
+  field = new Field(QLatin1String("plot"), i18n("Plot Summary"), Field::Para);
   list.append(field);
 
-  list.append(createDefaultField(IDField));
-  list.append(createDefaultField(CreatedDateField));
-  list.append(createDefaultField(ModifiedDateField));
+  field = new Field(QLatin1String("comments"), i18n("Comments"), Field::Para);
+  list.append(field);
+
+  list.append(Field::createDefaultField(Field::IDField));
+  list.append(Field::createDefaultField(Field::CreatedDateField));
+  list.append(Field::createDefaultField(Field::ModifiedDateField));
 
   return list;
 }
