@@ -48,7 +48,7 @@ Tellico::Data::FieldList VideoCollection::defaultFields() {
   FieldList list;
   FieldPtr field;
 
-  list.append(createDefaultField(TitleField));
+  list.append(Field::createDefaultField(Field::TitleField));
 
   QStringList media;
   media << i18n("DVD") << i18n("VHS") << i18n("VCD") << i18n("DivX") << i18n("Blu-ray") << i18n("HD DVD");
@@ -223,9 +223,9 @@ Tellico::Data::FieldList VideoCollection::defaultFields() {
   field = new Field(QLatin1String("comments"), i18n("Comments"), Field::Para);
   list.append(field);
 
-  list.append(createDefaultField(IDField));
-  list.append(createDefaultField(CreatedDateField));
-  list.append(createDefaultField(ModifiedDateField));
+  list.append(Field::createDefaultField(Field::IDField));
+  list.append(Field::createDefaultField(Field::CreatedDateField));
+  list.append(Field::createDefaultField(Field::ModifiedDateField));
 
   return list;
 }
@@ -246,4 +246,3 @@ int VideoCollection::sameEntry(Tellico::Data::EntryPtr entry1_, Tellico::Data::E
   res += 10*EntryComparison::score(entry1_, entry2_, QLatin1String("imdb"), this);
   return res;
 }
-
