@@ -22,33 +22,34 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <config.h>
+#include <config.h> // for TELLICO_VERSION
+
 #include "allocinefetcher.h"
 #include "../collections/videocollection.h"
+#include "../images/imagefactory.h"
 #include "../entry.h"
-#include "../gui/guiproxy.h"
-#include "../tellico_utils.h"
+#include "../utils/guiproxy.h"
+#include "../utils/string_utils.h"
 #include "../core/filehandler.h"
 #include "../tellico_debug.h"
 
-#include <kio/job.h>
-#include <kio/jobuidelegate.h>
-#include <KLocale>
+#include <KIO/Job>
+#include <KIO/JobUiDelegate>
+#include <KLocalizedString>
+#include <KJobWidgets/KJobWidgets>
 #include <KConfigGroup>
-#include <KLineEdit>
-#include <KIntSpinBox>
-#include <KCodecs>
 
+#include <QSpinBox>
+#include <QUrl>
 #include <QLabel>
 #include <QFile>
 #include <QTextStream>
 #include <QGridLayout>
 #include <QTextCodec>
 #include <QCryptographicHash>
-
-#ifdef HAVE_QJSON
-#include <qjson/parser.h>
-#endif
+#include <QJsonDocument>
+#include <QJsonObject>
+#include <QUrlQuery>
 
 namespace {
   static const char* ALLOCINE_API_KEY = "100043982026";
@@ -73,11 +74,7 @@ AbstractAllocineFetcher::~AbstractAllocineFetcher() {
 }
 
 bool AbstractAllocineFetcher::canSearch(FetchKey k) const {
-#ifdef HAVE_QJSON
   return k == Keyword;
-#else
-  return false;
-#endif
 }
 
 bool AbstractAllocineFetcher::canFetch(int type) const {
@@ -95,9 +92,10 @@ void AbstractAllocineFetcher::readConfigHook(const KConfigGroup& config_) {
 void AbstractAllocineFetcher::search() {
   m_started = true;
 
-#ifdef HAVE_QJSON
-  KUrl u(m_baseUrl);
-  u.addPath(QLatin1String("search"));
+  QUrl u(m_baseUrl);
+  u = u.adjusted(QUrl::StripTrailingSlash);
+  u.setPath(u.path() + QLatin1Char('/') + QLatin1String("search"));
+//  myDebug() << u;
 
   // the order of the parameters appears to matter
   QList<QPair<QString, QString> > params;
@@ -106,7 +104,9 @@ void AbstractAllocineFetcher::search() {
   // I can't figure out how to encode accent marks, but they don't
   // seem to be necessary
   QString q = removeAccents(request().value);
-  q.remove(QLatin1Char(','));
+  // should I just remove all non alphabetical characters?
+  // see https://bugs.kde.org/show_bug.cgi?id=337432
+  q.remove(QRegExp(QLatin1String("[,:!?;\\(\\)]")));
   q.replace(QLatin1Char('\''), QLatin1Char('+'));
   q.replace(QLatin1Char(' '), QLatin1Char('+'));
 
@@ -123,21 +123,23 @@ void AbstractAllocineFetcher::search() {
   params.append(qMakePair(QString::fromLatin1("format"), QString::fromLatin1("json")));
   params.append(qMakePair(QString::fromLatin1("filter"), QString::fromLatin1("movie")));
 
-  const QString sed = QDateTime::currentDateTime().toUTC().toString(QLatin1String("yyyyMMdd"));
+  const QString sed = QDateTime::currentDateTimeUtc().toString(QLatin1String("yyyyMMdd"));
   params.append(qMakePair(QString::fromLatin1("sed"), sed));
 
   const QByteArray sig = calculateSignature(params);
 
-  u.setQueryItems(params);
-  u.addQueryItem(QLatin1String("sig"), QLatin1String(sig));
-//  myDebug() << "url:" << u;
+  QUrlQuery query;
+  query.setQueryItems(params);
+  query.addQueryItem(QLatin1String("sig"), QLatin1String(sig));
+  u.setQuery(query);
+//  myDebug() << u;
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
-  m_job->ui()->setWindow(GUI::Proxy::widget());
+  // 10/8/17: UserAgent appears necessary to receive data
+  m_job->addMetaData(QLatin1String("UserAgent"), QString::fromLatin1("Tellico/%1")
+                                                                .arg(QLatin1String(TELLICO_VERSION)));
+  KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job, SIGNAL(result(KJob*)), SLOT(slotComplete(KJob*)));
-#else
-  stop();
-#endif
 }
 
 void AbstractAllocineFetcher::stop() {
@@ -160,12 +162,14 @@ Tellico::Data::EntryPtr AbstractAllocineFetcher::fetchEntryHook(uint uid_) {
 
   QString code = entry->field(QLatin1String("allocine-code"));
   if(code.isEmpty()) {
-    myWarning() << "no allocine release found";
+    // could mean we already updated the entry
+    myDebug() << "no allocine release found";
     return entry;
   }
 
-  KUrl u(m_baseUrl);
-  u.addPath(QLatin1String("movie"));
+  QUrl u(m_baseUrl);
+  u = u.adjusted(QUrl::StripTrailingSlash);
+  u.setPath(u.path() + QLatin1Char('/') + QLatin1String("movie"));
 
   // the order of the parameters appears to matter
   QList<QPair<QString, QString> > params;
@@ -175,19 +179,29 @@ Tellico::Data::EntryPtr AbstractAllocineFetcher::fetchEntryHook(uint uid_) {
   params.append(qMakePair(QString::fromLatin1("filter"), QString::fromLatin1("movie")));
   params.append(qMakePair(QString::fromLatin1("format"), QString::fromLatin1("json")));
 
-  const QString sed = QDateTime::currentDateTime().toUTC().toString(QLatin1String("yyyyMMdd"));
+  const QString sed = QDateTime::currentDateTimeUtc().toString(QLatin1String("yyyyMMdd"));
   params.append(qMakePair(QString::fromLatin1("sed"), sed));
 
   const QByteArray sig = calculateSignature(params);
 
-  u.setQueryItems(params);
-  u.addQueryItem(QLatin1String("sig"), QLatin1String(sig));
+  QUrlQuery query;
+  query.setQueryItems(params);
+  query.addQueryItem(QLatin1String("sig"), QLatin1String(sig));
+  u.setQuery(query);
 //  myDebug() << "url: " << u;
-  // quiet
-  QByteArray data = FileHandler::readDataFile(u, true);
+  // 10/8/17: UserAgent appears necessary to receive data
+//  QByteArray data = FileHandler::readDataFile(u, true);
+  KIO::StoredTransferJob* dataJob = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
+  dataJob->addMetaData(QLatin1String("UserAgent"), QString::fromLatin1("Tellico/%1")
+                                                                  .arg(QLatin1String(TELLICO_VERSION)));
+  if(!dataJob->exec()) {
+    myDebug() << "Failed to load" << u;
+    return entry;
+  }
+  const QByteArray data = dataJob->data();
 
 #if 0
-  myWarning() << "Remove debug from allocinefetcher.cpp";
+  myWarning() << "Remove debug2 from allocinefetcher.cpp";
   QFile f(QString::fromLatin1("/tmp/test2.json"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
@@ -197,16 +211,35 @@ Tellico::Data::EntryPtr AbstractAllocineFetcher::fetchEntryHook(uint uid_) {
   f.close();
 #endif
 
-#ifdef HAVE_QJSON
-  QJson::Parser parser;
-  bool ok;
-  QVariantMap result = parser.parse(data, &ok).toMap().value(QLatin1String("movie")).toMap();
-  if(!ok) {
+  QJsonParseError error;
+  QJsonDocument doc = QJsonDocument::fromJson(data, &error);
+  QVariantMap result = doc.object().toVariantMap().value(QLatin1String("movie")).toMap();
+  if(error.error != QJsonParseError::NoError) {
     myDebug() << "Bad JSON results";
+#if 0
+    myWarning() << "Remove debug3 from allocinefetcher.cpp";
+    QFile f2(QString::fromLatin1("/tmp/test3.json"));
+    if(f2.open(QIODevice::WriteOnly)) {
+      QTextStream t(&f2);
+      t.setCodec("UTF-8");
+      t << data;
+    }
+    f2.close();
+#endif
     return entry;
   }
   populateEntry(entry, result);
-#endif
+
+  // image might still be a URL
+  const QString image_id = entry->field(QLatin1String("cover"));
+  if(image_id.contains(QLatin1Char('/'))) {
+    const QString id = ImageFactory::addImage(QUrl::fromUserInput(image_id), true /* quiet */);
+    if(id.isEmpty()) {
+      message(i18n("The cover image could not be loaded."), MessageHandler::Warning);
+    }
+    // empty image ID is ok
+    entry->setField(QLatin1String("cover"), id);
+  }
 
   // don't want to include id
   entry->collection()->removeField(QLatin1String("allocine-code"));
@@ -219,11 +252,8 @@ Tellico::Data::EntryPtr AbstractAllocineFetcher::fetchEntryHook(uint uid_) {
 }
 
 void AbstractAllocineFetcher::slotComplete(KJob*) {
-#ifdef HAVE_QJSON
-//  myDebug();
-
   if(m_job->error()) {
-    m_job->ui()->showErrorMessage();
+    m_job->uiDelegate()->showErrorMessage();
     stop();
     return;
   }
@@ -236,7 +266,7 @@ void AbstractAllocineFetcher::slotComplete(KJob*) {
   }
   // see bug 319662. If fetcher is cancelled, job is killed
   // if the pointer is retained, it gets double-deleted
-  m_job = 0;
+  m_job = nullptr;
 
 #if 0
   myWarning() << "Remove debug from allocinefetcher.cpp";
@@ -249,9 +279,38 @@ void AbstractAllocineFetcher::slotComplete(KJob*) {
   f.close();
 #endif
 
+  QJsonDocument doc = QJsonDocument::fromJson(data);
+  QVariantMap result = doc.object().toVariantMap().value(QLatin1String("feed")).toMap();
+//  myDebug() << "total:" << result.value(QLatin1String("totalResults"));
+
+  QVariantList resultList = result.value(QLatin1String("movie")).toList();
+  if(resultList.isEmpty()) {
+    myDebug() << "no results";
+    stop();
+    return;
+  }
+
+  foreach(const QVariant& result, resultList) {
+  //  myDebug() << "found result:" << result;
+
+    //create a new collection for every result since we end up removing the allocine code field
+    // when fetchEntryHook is called. See bug 338389
+    Data::EntryPtr entry(new Data::Entry(createCollection()));
+    populateEntry(entry, result.toMap());
+
+    FetchResult* r = new FetchResult(Fetcher::Ptr(this), entry);
+    m_entries.insert(r->uid, entry);
+    emit signalResultFound(r);
+  }
+
+  m_hasMoreResults = false;
+  stop();
+}
+
+Tellico::Data::CollPtr AbstractAllocineFetcher::createCollection() const {
   Data::CollPtr coll(new Data::VideoCollection(true));
-  // always add the gbs-link for fetchEntryHook
-  Data::FieldPtr field(new Data::Field(QLatin1String("allocine-code"), QLatin1String("Allocine Code"), Data::Field::URL));
+  // always add the allocine release code for fetchEntryHook
+  Data::FieldPtr field(new Data::Field(QLatin1String("allocine-code"), QLatin1String("Allocine Code"), Data::Field::Number));
   field->setCategory(i18n("General"));
   coll->addField(field);
 
@@ -267,69 +326,44 @@ void AbstractAllocineFetcher::slotComplete(KJob*) {
     coll->addField(f);
   }
 
-
-  QJson::Parser parser;
-  QVariantMap result = parser.parse(data).toMap().value(QLatin1String("feed")).toMap();
-//  myDebug() << "total:" << result.value(QLatin1String("totalResults"));
-
-  QVariantList resultList = result.value(QLatin1String("movie")).toList();
-  if(resultList.isEmpty()) {
-    myDebug() << "no results";
-    stop();
-    return;
-  }
-
-  foreach(const QVariant& result, resultList) {
-  //  myDebug() << "found result:" << result;
-
-    Data::EntryPtr entry(new Data::Entry(coll));
-    populateEntry(entry, result.toMap());
-
-    FetchResult* r = new FetchResult(Fetcher::Ptr(this), entry);
-    m_entries.insert(r->uid, entry);
-    emit signalResultFound(r);
-  }
-
-  m_hasMoreResults = false;
-#endif
-  stop();
+  return coll;
 }
 
 void AbstractAllocineFetcher::populateEntry(Data::EntryPtr entry, const QVariantMap& resultMap) {
   if(entry->collection()->hasField(QLatin1String("allocine-code"))) {
-    entry->setField(QLatin1String("allocine-code"), value(resultMap, "code"));
+    entry->setField(QLatin1String("allocine-code"), mapValue(resultMap, "code"));
   }
 
-  entry->setField(QLatin1String("title"), value(resultMap, "title"));
+  entry->setField(QLatin1String("title"), mapValue(resultMap, "title"));
   if(optionalFields().contains(QLatin1String("origtitle"))) {
-    entry->setField(QLatin1String("origtitle"), value(resultMap, "originalTitle"));
+    entry->setField(QLatin1String("origtitle"), mapValue(resultMap, "originalTitle"));
   }
   if(entry->title().isEmpty()) {
-    entry->setField(QLatin1String("title"), value(resultMap,  "originalTitle"));
+    entry->setField(QLatin1String("title"), mapValue(resultMap,  "originalTitle"));
   }
-  entry->setField(QLatin1String("year"), value(resultMap, "productionYear"));
-  entry->setField(QLatin1String("plot"), value(resultMap, "synopsis"));
+  entry->setField(QLatin1String("year"), mapValue(resultMap, "productionYear"));
+  entry->setField(QLatin1String("plot"), mapValue(resultMap, "synopsis"));
 
-  const int runTime = value(resultMap, "runtime").toInt();
+  const int runTime = mapValue(resultMap, "runtime").toInt();
   entry->setField(QLatin1String("running-time"), QString::number(runTime/60));
 
   const QVariantList castList = resultMap.value(QLatin1String("castMember")).toList();
   QStringList actors, directors, producers, composers;
   foreach(const QVariant& castVariant, castList) {
     const QVariantMap castMap = castVariant.toMap();
-    const int code = value(castMap, "activity", "code").toInt();
+    const int code = mapValue(castMap, "activity", "code").toInt();
     switch(code) {
       case 8001:
-        actors << (value(castMap, "person", "name") + FieldFormat::columnDelimiterString() + value(castMap, "role"));
+        actors << (mapValue(castMap, "person", "name") + FieldFormat::columnDelimiterString() + mapValue(castMap, "role"));
         break;
       case 8002:
-        directors << value(castMap, "person", "name");
+        directors << mapValue(castMap, "person", "name");
         break;
       case 8029:
-        producers << value(castMap, "person", "name");
+        producers << mapValue(castMap, "person", "name");
         break;
       case 8003:
-        composers << value(castMap, "person", "name");
+        composers << mapValue(castMap, "person", "name");
         break;
     }
   }
@@ -339,23 +373,23 @@ void AbstractAllocineFetcher::populateEntry(Data::EntryPtr entry, const QVariant
   entry->setField(QLatin1String("composer"), composers.join(FieldFormat::delimiterString()));
 
   const QVariantMap releaseMap = resultMap.value(QLatin1String("release")).toMap();
-  entry->setField(QLatin1String("studio"), value(releaseMap, "distributor", "name"));
+  entry->setField(QLatin1String("studio"), mapValue(releaseMap, "distributor", "name"));
 
   QStringList genres;
   foreach(const QVariant& variant, resultMap.value(QLatin1String("genre")).toList()) {
-    genres << i18n(value(variant.toMap(), "$").toUtf8());
+    genres << i18n(mapValue(variant.toMap(), "$").toUtf8().constData());
   }
   entry->setField(QLatin1String("genre"), genres.join(FieldFormat::delimiterString()));
 
   QStringList nats;
   foreach(const QVariant& variant, resultMap.value(QLatin1String("nationality")).toList()) {
-    nats << value(variant.toMap(), "$");
+    nats << mapValue(variant.toMap(), "$");
   }
   entry->setField(QLatin1String("nationality"), nats.join(FieldFormat::delimiterString()));
 
   QStringList langs;
   foreach(const QVariant& variant, resultMap.value(QLatin1String("language")).toList()) {
-    langs << value(variant.toMap(), "$");
+    langs << mapValue(variant.toMap(), "$");
   }
   entry->setField(QLatin1String("language"), langs.join(FieldFormat::delimiterString()));
 
@@ -364,10 +398,10 @@ void AbstractAllocineFetcher::populateEntry(Data::EntryPtr entry, const QVariant
     entry->setField(QLatin1String("color"), i18n("Color"));
   }
 
-  entry->setField(QLatin1String("cover"), value(resultMap, "poster", "href"));
+  entry->setField(QLatin1String("cover"), mapValue(resultMap, "poster", "href"));
 
   if(optionalFields().contains(QLatin1String("allocine"))) {
-    entry->setField(QLatin1String("allocine"), value(resultMap, "link", "href"));
+    entry->setField(QLatin1String("allocine"), mapValue(resultMap, "link", "href"));
   }
 }
 
@@ -389,7 +423,10 @@ AbstractAllocineFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const Abst
 
   QLabel* label = new QLabel(i18n("&Maximum cast: "), optionsWidget());
   l->addWidget(label, ++row, 0);
-  m_numCast = new KIntSpinBox(0, 99, 1, 10, optionsWidget());
+  m_numCast = new QSpinBox(optionsWidget());
+  m_numCast->setMaximum(99);
+  m_numCast->setMinimum(0);
+  m_numCast->setValue(10);
   connect(m_numCast, SIGNAL(valueChanged(const QString&)), SLOT(slotSetModified()));
   l->addWidget(m_numCast, row, 1);
   QString w = i18n("The list of cast members may include many people. Set the maximum number returned from the search.");
@@ -406,34 +443,6 @@ void AbstractAllocineFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_
   config_.writeEntry("Max Cast", m_numCast->value());
 }
 
-// static
-QString AbstractAllocineFetcher::value(const QVariantMap& map, const char* name) {
-  const QVariant v = map.value(QLatin1String(name));
-  if(v.isNull())  {
-    return QString();
-  } else if(v.canConvert(QVariant::String)) {
-    return v.toString();
-  } else if(v.canConvert(QVariant::StringList)) {
-    return v.toStringList().join(Tellico::FieldFormat::delimiterString());
-  } else {
-    return QString();
-  }
-}
-
-QString AbstractAllocineFetcher::value(const QVariantMap& map, const char* object, const char* name) {
-  const QVariant v = map.value(QLatin1String(object));
-  if(v.isNull())  {
-    return QString();
-  } else if(v.canConvert(QVariant::Map)) {
-    return value(v.toMap(), name);
-  } else if(v.canConvert(QVariant::List)) {
-    QVariantList list = v.toList();
-    return list.isEmpty() ? QString() : value(list.at(0).toMap(), name);
-  } else {
-    return QString();
-  }
-}
-
 QByteArray AbstractAllocineFetcher::calculateSignature(const QList<QPair<QString, QString> >& params_) {
   typedef QPair<QString, QString> StringPair;
   QByteArray queryString;
@@ -448,7 +457,7 @@ QByteArray AbstractAllocineFetcher::calculateSignature(const QList<QPair<QString
 
   const QByteArray toSign = ALLOCINE_PARTNER_KEY + queryString;
   const QByteArray hash = QCryptographicHash::hash(toSign, QCryptographicHash::Sha1);
-  const QByteArray sig = KCodecs::base64Encode(hash);
+  QByteArray sig = hash.toBase64();
   return sig;
 }
 
@@ -490,5 +499,3 @@ AllocineFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const AbstractAllo
 QString AllocineFetcher::ConfigWidget::preferredName() const {
   return AllocineFetcher::defaultName();
 }
-
-#include "allocinefetcher.moc"
