@@ -29,29 +29,27 @@
 #include "../translators/xslthandler.h"
 #include "../translators/tellicoimporter.h"
 #include "../images/imagefactory.h"
-#include "../gui/guiproxy.h"
+#include "../utils/guiproxy.h"
 #include "../collection.h"
-#include "../document.h"
 #include "../entry.h"
 #include "../field.h"
 #include "../fieldformat.h"
-#include "../tellico_utils.h"
+#include "../utils/string_utils.h"
 #include "../utils/isbnvalidator.h"
-#include "../utils/wallet.h"
+#include "../utils/datafileregistry.h"
 #include "../gui/combobox.h"
 #include "../tellico_debug.h"
 
-#include <klocale.h>
-#include <kio/job.h>
-#include <kio/jobuidelegate.h>
-#include <kstandarddirs.h>
-#include <kconfig.h>
-#include <klineedit.h>
-#include <kseparator.h>
-#include <kcombobox.h>
-#include <kacceleratormanager.h>
+#include <KLocalizedString>
+#include <KIO/Job>
+#include <KIO/JobUiDelegate>
+#include <KSeparator>
+#include <KComboBox>
+#include <KAcceleratorManager>
 #include <KConfigGroup>
+#include <KJobWidgets/KJobWidgets>
 
+#include <QLineEdit>
 #include <QDomDocument>
 #include <QLabel>
 #include <QCheckBox>
@@ -78,31 +76,31 @@ const AmazonFetcher::SiteData& AmazonFetcher::siteData(int site_) {
   static SiteData dataVector[9] = {
     {
       i18n("Amazon (US)"),
-      KUrl("http://webservices.amazon.com/onca/xml")
+      QUrl(QLatin1String("http://webservices.amazon.com/onca/xml"))
     }, {
       i18n("Amazon (UK)"),
-      KUrl("http://webservices.amazon.co.uk/onca/xml")
+      QUrl(QLatin1String("http://webservices.amazon.co.uk/onca/xml"))
     }, {
       i18n("Amazon (Germany)"),
-      KUrl("http://webservices.amazon.de/onca/xml")
+      QUrl(QLatin1String("http://webservices.amazon.de/onca/xml"))
     }, {
       i18n("Amazon (Japan)"),
-      KUrl("http://webservices.amazon.co.jp/onca/xml")
+      QUrl(QLatin1String("http://webservices.amazon.co.jp/onca/xml"))
     }, {
       i18n("Amazon (France)"),
-      KUrl("http://webservices.amazon.fr/onca/xml")
+      QUrl(QLatin1String("http://webservices.amazon.fr/onca/xml"))
     }, {
       i18n("Amazon (Canada)"),
-      KUrl("http://webservices.amazon.ca/onca/xml")
+      QUrl(QLatin1String("http://webservices.amazon.ca/onca/xml"))
     }, {
       i18n("Amazon (China)"),
-      KUrl("http://webservices.amazon.cn/onca/xml")
+      QUrl(QLatin1String("http://webservices.amazon.cn/onca/xml"))
     }, {
       i18n("Amazon (Spain)"),
-      KUrl("http://webservices.amazon.es/onca/xml")
+      QUrl(QLatin1String("http://webservices.amazon.es/onca/xml"))
     }, {
       i18n("Amazon (Italy)"),
-      KUrl("http://webservices.amazon.it/onca/xml")
+      QUrl(QLatin1String("http://webservices.amazon.it/onca/xml"))
     }
   };
 
@@ -110,15 +108,15 @@ const AmazonFetcher::SiteData& AmazonFetcher::siteData(int site_) {
 }
 
 AmazonFetcher::AmazonFetcher(QObject* parent_)
-    : Fetcher(parent_), m_xsltHandler(0), m_site(Unknown), m_imageSize(MediumImage),
+    : Fetcher(parent_), m_xsltHandler(nullptr), m_site(Unknown), m_imageSize(MediumImage),
       m_assoc(QLatin1String(AMAZON_ASSOC_TOKEN)), m_addLinkField(true), m_limit(AMAZON_MAX_RETURNS_TOTAL),
-      m_countOffset(0), m_page(1), m_total(-1), m_numResults(0), m_job(0), m_started(false), m_keyFoundInWallet(false) {
+      m_countOffset(0), m_page(1), m_total(-1), m_numResults(0), m_job(nullptr), m_started(false) {
   (void)linkText; // just to shut up the compiler
 }
 
 AmazonFetcher::~AmazonFetcher() {
   delete m_xsltHandler;
-  m_xsltHandler = 0;
+  m_xsltHandler = nullptr;
 }
 
 QString AmazonFetcher::source() const {
@@ -178,15 +176,6 @@ void AmazonFetcher::readConfigHook(const KConfigGroup& config_) {
   }
 }
 
-// just in case the secret key was once saved in the wallet
-// be sure to save it back in the rc file
-void AmazonFetcher::saveConfigHook(KConfigGroup& config_) {
-  if(!secretKey().isEmpty() && m_keyFoundInWallet) {
-    config_.writeEntry("SecretKey", m_amazonKey);
-    config_.sync();
-  }
-}
-
 void AmazonFetcher::search() {
   m_started = true;
   m_page = 1;
@@ -390,11 +379,11 @@ void AmazonFetcher::doSearch() {
   }
 
   AmazonRequest request(siteData(m_site).url, m_amazonKey);
-  KUrl newUrl = request.signedRequest(params);
+  QUrl newUrl = request.signedRequest(params);
 //  myDebug() << newUrl;
 
   m_job = KIO::storedGet(newUrl, KIO::NoReload, KIO::HideProgressInfo);
-  m_job->ui()->setWindow(GUI::Proxy::widget());
+  KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job, SIGNAL(result(KJob*)),
           SLOT(slotComplete(KJob*)));
 }
@@ -406,7 +395,7 @@ void AmazonFetcher::stop() {
 //  myDebug();
   if(m_job) {
     m_job->kill();
-    m_job = 0;
+    m_job = nullptr;
   }
   m_started = false;
   emit signalDone(this);
@@ -416,7 +405,7 @@ void AmazonFetcher::slotComplete(KJob*) {
 //  myDebug();
 
   if(m_job->error()) {
-    m_job->ui()->showErrorMessage();
+    m_job->uiDelegate()->showErrorMessage();
     stop();
     return;
   }
@@ -429,7 +418,7 @@ void AmazonFetcher::slotComplete(KJob*) {
   }
 
   // since the fetch is done, don't worry about holding the job pointer
-  m_job = 0;
+  m_job = nullptr;
 
 #if 0
   myWarning() << "Remove debug from amazonfetcher.cpp";
@@ -450,6 +439,15 @@ void AmazonFetcher::slotComplete(KJob*) {
       stop();
       return;
     }
+    // check for ItemSearchErrorResponse
+    if(dom.documentElement().tagName() == QLatin1String("ItemSearchErrorResponse")) {
+      QDomNode n = dom.documentElement().namedItem(QLatin1String("Error")).namedItem(QLatin1String("Message"));
+      if(!n.isNull()) {
+        message(n.toElement().text(), MessageHandler::Error);
+        stop();
+        return;
+      }
+    }
     // find TotalResults element
     // it's in the first level under the root element
     //ItemSearchResponse/Items/TotalResults
@@ -497,7 +495,7 @@ void AmazonFetcher::slotComplete(KJob*) {
 //  stripHTML.setMinimal(true);
 
   // assume amazon is always utf-8
-  QString str = m_xsltHandler->applyStylesheet(QString::fromUtf8(data, data.size()));
+  QString str = m_xsltHandler->applyStylesheet(QString::fromUtf8(data.constData(), data.size()));
   Import::TellicoImporter imp(str);
   // be quiet when loading images
   imp.setOptions(imp.options() ^ Import::ImportShowImageErrors);
@@ -554,7 +552,7 @@ void AmazonFetcher::slotComplete(KJob*) {
       QString t = entry->title();
       if(rx.indexIn(t) > -1) {
         QString y = rx.cap(1);
-        t.remove(rx).simplified();
+        t = t.remove(rx).simplified();
         entry->setField(QLatin1String("title"), t);
         if(entry->field(QLatin1String("year")).isEmpty()) {
           entry->setField(QLatin1String("year"), y);
@@ -628,7 +626,7 @@ Tellico::Data::EntryPtr AmazonFetcher::fetchEntryHook(uint uid_) {
     case Data::Collection::Book:
     case Data::Collection::ComicBook:
     case Data::Collection::Bibtex:
-      {
+      if(optionalFields().contains(QLatin1String("keyword"))) {
         StringSet newWords;
         const QStringList keywords = FieldFormat::splitValue(entry->field(QLatin1String("keyword")));
         foreach(const QString& keyword, keywords) {
@@ -723,7 +721,7 @@ Tellico::Data::EntryPtr AmazonFetcher::fetchEntryHook(uint uid_) {
   }
 
   // clean up the title
-  parseTitle(entry, type);
+  parseTitle(entry);
 
   // also sometimes table fields have rows but no values
   Data::FieldList fields = entry->collection()->fields();
@@ -740,7 +738,7 @@ Tellico::Data::EntryPtr AmazonFetcher::fetchEntryHook(uint uid_) {
     }
   }
 
-  KUrl imageURL;
+  QString imageURL;
   switch(m_imageSize) {
     case SmallImage:
       imageURL = entry->field(QLatin1String("small-image"));
@@ -755,9 +753,9 @@ Tellico::Data::EntryPtr AmazonFetcher::fetchEntryHook(uint uid_) {
     default:
       break;
   }
-//  myDebug() << "grabbing " << imageURL.prettyUrl();
+//  myDebug() << "grabbing " << imageURL.toDisplayString();
   if(!imageURL.isEmpty()) {
-    QString id = ImageFactory::addImage(imageURL, true);
+    QString id = ImageFactory::addImage(QUrl::fromUserInput(imageURL), true);
     if(id.isEmpty()) {
       message(i18n("The cover image could not be loaded."), MessageHandler::Warning);
     } else { // amazon serves up 1x1 gifs occasionally, but that's caught in the image constructor
@@ -774,21 +772,20 @@ Tellico::Data::EntryPtr AmazonFetcher::fetchEntryHook(uint uid_) {
 }
 
 void AmazonFetcher::initXSLTHandler() {
-  QString xsltfile = KStandardDirs::locate("appdata", QLatin1String("amazon2tellico.xsl"));
+  QString xsltfile = DataFileRegistry::self()->locate(QLatin1String("amazon2tellico.xsl"));
   if(xsltfile.isEmpty()) {
     myWarning() << "can not locate amazon2tellico.xsl.";
     return;
   }
 
-  KUrl u;
-  u.setPath(xsltfile);
+  QUrl u = QUrl::fromLocalFile(xsltfile);
 
   delete m_xsltHandler;
   m_xsltHandler = new XSLTHandler(u);
   if(!m_xsltHandler->isValid()) {
     myWarning() << "error in amazon2tellico.xsl.";
     delete m_xsltHandler;
-    m_xsltHandler = 0;
+    m_xsltHandler = nullptr;
     return;
   }
 }
@@ -822,80 +819,75 @@ Tellico::Fetch::FetchRequest AmazonFetcher::updateRequest(Data::EntryPtr entry_)
   return FetchRequest();
 }
 
-void AmazonFetcher::parseTitle(Tellico::Data::EntryPtr entry, int collType) {
-  Q_UNUSED(collType);
+void AmazonFetcher::parseTitle(Tellico::Data::EntryPtr entry_) {
   // assume that everything in brackets or parentheses is extra
   QRegExp rx(QLatin1String("[\\(\\[](.*)[\\)\\]]"));
   rx.setMinimal(true);
-  QString title = entry->field(QLatin1String("title"));
+  QString title = entry_->field(QLatin1String("title"));
   int pos = rx.indexIn(title);
   while(pos > -1) {
-    if(parseTitleToken(entry, rx.cap(1))) {
+    if(parseTitleToken(entry_, rx.cap(1))) {
       title.remove(pos, rx.matchedLength());
       --pos; // search again there
     }
     pos = rx.indexIn(title, pos+1);
   }
-  entry->setField(QLatin1String("title"), title.trimmed());
+  entry_->setField(QLatin1String("title"), title.trimmed());
 }
 
-bool AmazonFetcher::parseTitleToken(Tellico::Data::EntryPtr entry, const QString& token) {
-//  myDebug() << "title token:" << token;
+bool AmazonFetcher::parseTitleToken(Tellico::Data::EntryPtr entry_, const QString& token_) {
+//  myDebug() << "title token:" << token_;
   // if res = true, then the token gets removed from the title
   bool res = false;
-  if(token.indexOf(QLatin1String("widescreen"), 0, Qt::CaseInsensitive) > -1 ||
-     token.indexOf(i18n("Widescreen"), 0, Qt::CaseInsensitive) > -1) {
-    entry->setField(QLatin1String("widescreen"), QLatin1String("true"));
+  if(token_.indexOf(QLatin1String("widescreen"), 0, Qt::CaseInsensitive) > -1 ||
+     token_.indexOf(i18n("Widescreen"), 0, Qt::CaseInsensitive) > -1) {
+    entry_->setField(QLatin1String("widescreen"), QLatin1String("true"));
     // res = true; leave it in the title
-  } else if(token.indexOf(QLatin1String("full screen"), 0, Qt::CaseInsensitive) > -1) {
+  } else if(token_.indexOf(QLatin1String("full screen"), 0, Qt::CaseInsensitive) > -1) {
     // skip, but go ahead and remove from title
     res = true;
-  } else if(token.indexOf(QLatin1String("import"), 0, Qt::CaseInsensitive) > -1) {
+  } else if(token_.indexOf(QLatin1String("import"), 0, Qt::CaseInsensitive) > -1) {
     // skip, but go ahead and remove from title
     res = true;
   }
-  if(token.indexOf(QLatin1String("blu-ray"), 0, Qt::CaseInsensitive) > -1) {
-    entry->setField(QLatin1String("medium"), i18n("Blu-ray"));
+  if(token_.indexOf(QLatin1String("blu-ray"), 0, Qt::CaseInsensitive) > -1) {
+    entry_->setField(QLatin1String("medium"), i18n("Blu-ray"));
     res = true;
-  } else if(token.indexOf(QLatin1String("hd dvd"), 0, Qt::CaseInsensitive) > -1) {
-    entry->setField(QLatin1String("medium"), i18n("HD DVD"));
+  } else if(token_.indexOf(QLatin1String("hd dvd"), 0, Qt::CaseInsensitive) > -1) {
+    entry_->setField(QLatin1String("medium"), i18n("HD DVD"));
     res = true;
-  } else if(token.indexOf(QLatin1String("vhs"), 0, Qt::CaseInsensitive) > -1) {
-    entry->setField(QLatin1String("medium"), i18n("VHS"));
+  } else if(token_.indexOf(QLatin1String("vhs"), 0, Qt::CaseInsensitive) > -1) {
+    entry_->setField(QLatin1String("medium"), i18n("VHS"));
     res = true;
   }
-  if(token.indexOf(QLatin1String("director's cut"), 0, Qt::CaseInsensitive) > -1 ||
-     token.indexOf(i18n("Director's Cut"), 0, Qt::CaseInsensitive) > -1) {
-    entry->setField(QLatin1String("directors-cut"), QLatin1String("true"));
+  if(token_.indexOf(QLatin1String("director's cut"), 0, Qt::CaseInsensitive) > -1 ||
+     token_.indexOf(i18n("Director's Cut"), 0, Qt::CaseInsensitive) > -1) {
+    entry_->setField(QLatin1String("directors-cut"), QLatin1String("true"));
     // res = true; leave it in the title
   }
-  if(token.toLower() == QLatin1String("ntsc")) {
-    entry->setField(QLatin1String("format"), i18n("NTSC"));
+  if(token_.toLower() == QLatin1String("ntsc")) {
+    entry_->setField(QLatin1String("format"), i18n("NTSC"));
     res = true;
   }
-  if(token.toLower() == QLatin1String("dvd")) {
-    entry->setField(QLatin1String("medium"), i18n("DVD"));
+  if(token_.toLower() == QLatin1String("dvd")) {
+    entry_->setField(QLatin1String("medium"), i18n("DVD"));
     res = true;
   }
   static QRegExp regionRx(QLatin1String("Region [1-9]"));
-  if(regionRx.indexIn(token) > -1) {
-    entry->setField(QLatin1String("region"), i18n(regionRx.cap(0).toUtf8()));
+  if(regionRx.indexIn(token_) > -1) {
+    entry_->setField(QLatin1String("region"), i18n(regionRx.cap(0).toUtf8().constData()));
     res = true;
   }
+  if(entry_->collection()->type() == Data::Collection::Game) {
+    Data::FieldPtr f = entry_->collection()->fieldByName(QLatin1String("platform"));
+    if(f && f->allowed().contains(token_)) {
+      res = true;
+    }
+  }
   return res;
 }
 
 QString AmazonFetcher::secretKey() const {
-  if(m_amazonKey.isEmpty()) {
-    myWarning() << "Looking for the Amazon key in kwallet...";
-    QByteArray maybeKey = Wallet::self()->readWalletEntry(m_access);
-    if(!maybeKey.isEmpty()) {
-      m_amazonKey = maybeKey;
-      m_keyFoundInWallet = true;
-    } else {
-      myWarning() << "No Amazon secret key found for" << source();
-    }
-  }
   return QString::fromUtf8(m_amazonKey);
 }
 
@@ -905,7 +897,7 @@ QString AmazonFetcher::defaultName() {
 }
 
 QString AmazonFetcher::defaultIcon() {
-  return favIcon("http://amazon.com");
+  return favIcon("http://www.amazon.com");
 }
 
 Tellico::StringHash AmazonFetcher::allOptionalFields() {
@@ -941,7 +933,7 @@ AmazonFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const AmazonFetcher*
 
   QLabel* label = new QLabel(i18n("Access key: "), optionsWidget());
   l->addWidget(label, ++row, 0);
-  m_accessEdit = new KLineEdit(optionsWidget());
+  m_accessEdit = new QLineEdit(optionsWidget());
   connect(m_accessEdit, SIGNAL(textChanged(const QString&)), SLOT(slotSetModified()));
   l->addWidget(m_accessEdit, row, 1);
   QString w = i18n("Access to data from Amazon.com requires an AWS Access Key ID and a Secret Key.");
@@ -951,7 +943,7 @@ AmazonFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const AmazonFetcher*
 
   label = new QLabel(i18n("Secret key: "), optionsWidget());
   l->addWidget(label, ++row, 0);
-  m_secretKeyEdit = new KLineEdit(optionsWidget());
+  m_secretKeyEdit = new QLineEdit(optionsWidget());
 //  m_secretKeyEdit->setEchoMode(QLineEdit::PasswordEchoOnEdit);
   connect(m_secretKeyEdit, SIGNAL(textChanged(const QString&)), SLOT(slotSetModified()));
   l->addWidget(m_secretKeyEdit, row, 1);
@@ -997,7 +989,7 @@ AmazonFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const AmazonFetcher*
 
   label = new QLabel(i18n("&Associate's ID: "), optionsWidget());
   l->addWidget(label, ++row, 0);
-  m_assocEdit = new KLineEdit(optionsWidget());
+  m_assocEdit = new QLineEdit(optionsWidget());
   connect(m_assocEdit, SIGNAL(textChanged(const QString&)), SLOT(slotSetModified()));
   l->addWidget(m_assocEdit, row, 1);
   w = i18n("The associate's id identifies the person accessing the Amazon.com Web Services, and is included "
@@ -1050,5 +1042,3 @@ QString AmazonFetcher::ConfigWidget::preferredName() const {
 void AmazonFetcher::ConfigWidget::slotSiteChanged() {
   emit signalName(preferredName());
 }
-
-#include "amazonfetcher.moc"
