@@ -143,7 +143,7 @@ void BedethequeFetcher::stop() {
 
   if(m_job) {
     m_job->kill();
-    m_job = 0;
+    m_job = nullptr;
   }
   m_started = false;
   emit signalDone(this);
@@ -151,7 +151,7 @@ void BedethequeFetcher::stop() {
 
 void BedethequeFetcher::slotComplete(KJob*) {
   if(m_job->error()) {
-    m_job->ui()->showErrorMessage();
+    m_job->uiDelegate()->showErrorMessage();
     stop();
     return;
   }
@@ -164,7 +164,7 @@ void BedethequeFetcher::slotComplete(KJob*) {
   }
 
   // since the fetch is done, don't worry about holding the job pointer
-  m_job = 0;
+  m_job = nullptr;
 
   QString output = Tellico::decodeHTML(data);
 #if 0
@@ -233,7 +233,7 @@ void BedethequeFetcher::slotComplete(KJob*) {
 // slot called after downloading the exact link
 void BedethequeFetcher::slotLinkComplete(KJob*) {
   if(m_job->error()) {
-    m_job->ui()->showErrorMessage();
+    m_job->uiDelegate()->showErrorMessage();
     stop();
     return;
   }
@@ -245,7 +245,7 @@ void BedethequeFetcher::slotLinkComplete(KJob*) {
   }
 
   // since the fetch is done, don't worry about holding the job pointer
-  m_job = 0;
+  m_job = nullptr;
 
   QString output = Tellico::decodeHTML(data);
   Data::EntryPtr entry = parseEntry(output);
