@@ -265,6 +265,7 @@ void OMDBFetcher::slotComplete(KJob* job_) {
     return;
   }
 
+  int count = 0;
   foreach(const QVariant& result, resultList) {
 //    myDebug() << "found result:" << result;
 
@@ -274,6 +275,10 @@ void OMDBFetcher::slotComplete(KJob* job_) {
     FetchResult* r = new FetchResult(Fetcher::Ptr(this), entry);
     m_entries.insert(r->uid, entry);
     emit signalResultFound(r);
+    ++count;
+    if(count >= OMDB_MAX_RETURNS_TOTAL) {
+      break;
+    }
   }
 
   stop();
@@ -397,7 +402,11 @@ OMDBFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const OMDBFetcher* fet
   addFieldsWidget(OMDBFetcher::allOptionalFields(), fetcher_ ? fetcher_->optionalFields() : QStringList());
 }
 
-void OMDBFetcher::ConfigWidget::saveConfigHook(KConfigGroup&) {
+void OMDBFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
+  const QString apiKey = m_apiKeyEdit->text().trimmed();
+  if(!apiKey.isEmpty()) {
+    config_.writeEntry("API Key", apiKey);
+  }
 }
 
 QString OMDBFetcher::ConfigWidget::preferredName() const {
