@@ -22,30 +22,30 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <config.h>
 #include "openlibraryfetcher.h"
 #include "../collections/bookcollection.h"
 #include "../images/imagefactory.h"
 #include "../utils/isbnvalidator.h"
-#include "../gui/guiproxy.h"
-#include "../tellico_utils.h"
+#include "../utils/guiproxy.h"
+#include "../utils/string_utils.h"
 #include "../entry.h"
 #include "../core/filehandler.h"
 #include "../tellico_debug.h"
 
-#include <klocale.h>
-#include <kio/job.h>
-#include <kio/jobuidelegate.h>
+#include <KLocalizedString>
+#include <KIO/Job>
+#include <KJobUiDelegate>
+#include <KJobWidgets/KJobWidgets>
 
 #include <QLabel>
 #include <QFile>
 #include <QTextStream>
 #include <QGridLayout>
 #include <QTextCodec>
-
-#ifdef HAVE_QJSON
-#include <qjson/parser.h>
-#endif
+#include <QJsonDocument>
+#include <QJsonObject>
+#include <QJsonArray>
+#include <QUrlQuery>
 
 namespace {
   static const char* OPENLIBRARY_QUERY_URL = "http://openlibrary.org/query.json";
@@ -65,13 +65,8 @@ QString OpenLibraryFetcher::source() const {
   return m_name.isEmpty() ? defaultName() : m_name;
 }
 
-// without QJSON, we can only search on ISBN for covers
 bool OpenLibraryFetcher::canSearch(FetchKey k) const {
-#ifndef HAVE_QJSON
-  return k == ISBN;
-#else
   return k == Title || k == Person || k == ISBN || k == LCCN || k == Keyword;
-#endif
 }
 
 bool OpenLibraryFetcher::canFetch(int type) const {
@@ -99,18 +94,15 @@ void OpenLibraryFetcher::search() {
 }
 
 void OpenLibraryFetcher::doSearch(const QString& term_) {
-#ifndef HAVE_QJSON
-  doCoverOnly(term_);
-#else
-  KUrl u(OPENLIBRARY_QUERY_URL);
-
+  QUrl u(QString::fromLatin1(OPENLIBRARY_QUERY_URL));
+  QUrlQuery q;
   // books are type/edition
-  u.addQueryItem(QLatin1String("type"), QLatin1String("/type/edition"));
-  u.addQueryItem(QLatin1String("*"), QString());
+  q.addQueryItem(QLatin1String("type"), QLatin1String("/type/edition"));
+  q.addQueryItem(QLatin1String("*"), QString());
 
   switch(request().key) {
     case Title:
-      u.addQueryItem(QLatin1String("title"), term_);
+      q.addQueryItem(QLatin1String("title"), term_);
       break;
 
     case Person:
@@ -120,7 +112,7 @@ void OpenLibraryFetcher::doSearch(const QString& term_) {
           myWarning() << "no authors found";
           return;
         }
-        u.addQueryItem(QLatin1String("authors"), author);
+        q.addQueryItem(QLatin1String("authors"), author);
       }
       break;
 
@@ -128,15 +120,15 @@ void OpenLibraryFetcher::doSearch(const QString& term_) {
       {
         const QString isbn = ISBNValidator::cleanValue(term_);
         if(isbn.size() > 10) {
-          u.addQueryItem(QLatin1String("isbn_13"), isbn);
+          q.addQueryItem(QLatin1String("isbn_13"), isbn);
         } else {
-          u.addQueryItem(QLatin1String("isbn_10"), isbn);
+          q.addQueryItem(QLatin1String("isbn_10"), isbn);
         }
       }
       break;
 
     case LCCN:
-      u.addQueryItem(QLatin1String("lccn"), term_);
+      q.addQueryItem(QLatin1String("lccn"), term_);
       break;
 
     case Keyword:
@@ -147,38 +139,13 @@ void OpenLibraryFetcher::doSearch(const QString& term_) {
       myWarning() << "key not recognized:" << request().key;
       return;
   }
-
+  u.setQuery(q);
 //  myDebug() << "url:" << u;
 
   QPointer<KIO::StoredTransferJob> job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
-  job->ui()->setWindow(GUI::Proxy::widget());
+  KJobWidgets::setWindow(job, GUI::Proxy::widget());
   connect(job, SIGNAL(result(KJob*)), SLOT(slotComplete(KJob*)));
   m_jobs << job;
-#endif
-}
-
-void OpenLibraryFetcher::doCoverOnly(const QString& term_) {
-  switch(request().key) {
-     case ISBN:
-       break;
-
-    default:
-      myWarning() << "key not recognized: " << request().key;
-      return;
-  }
-
-  int pos = 0;
-  ISBNValidator val(this);
-  QString isbn = term_;
-  if(val.validate(isbn, pos) == QValidator::Acceptable) {
-    Data::CollPtr coll(new Data::BookCollection(true));
-    Data::EntryPtr entry(new Data::Entry(coll));
-    entry->setField(QLatin1String("isbn"), isbn);
-
-    FetchResult* r = new FetchResult(Fetcher::Ptr(this), entry);
-    m_entries.insert(r->uid, Data::EntryPtr(entry));
-    emit signalResultFound(r);
-  }
 }
 
 void OpenLibraryFetcher::endJob(KIO::StoredTransferJob* job_) {
@@ -213,7 +180,7 @@ Tellico::Data::EntryPtr OpenLibraryFetcher::fetchEntryHook(uint uid_) {
   if(entry->field(QLatin1String("cover")).isEmpty()) {
     const QString isbn = ISBNValidator::cleanValue(entry->field(QLatin1String("isbn")));
     if(!isbn.isEmpty()) {
-      KUrl imageUrl = QString::fromLatin1("http://covers.openlibrary.org/b/isbn/%1-M.jpg?default=false").arg(isbn);
+      QUrl imageUrl(QString::fromLatin1("http://covers.openlibrary.org/b/isbn/%1-M.jpg?default=false").arg(isbn));
       const QString id = ImageFactory::addImage(imageUrl, true);
       if(!id.isEmpty()) {
         entry->setField(QLatin1String("cover"), id);
@@ -242,11 +209,10 @@ Tellico::Fetch::FetchRequest OpenLibraryFetcher::updateRequest(Data::EntryPtr en
 
 void OpenLibraryFetcher::slotComplete(KJob* job_) {
   KIO::StoredTransferJob* job = static_cast<KIO::StoredTransferJob*>(job_);
-#ifdef HAVE_QJSON
 //  myDebug();
 
   if(job->error()) {
-    job->ui()->showErrorMessage();
+    job->uiDelegate()->showErrorMessage();
     endJob(job);
     return;
   }
@@ -269,9 +235,9 @@ void OpenLibraryFetcher::slotComplete(KJob* job_) {
   f.close();
 #endif
 
-  QJson::Parser parser;
-  QVariantList resultList = parser.parse(data).toList();
-  if(resultList.isEmpty()) {
+  QJsonDocument doc = QJsonDocument::fromJson(data);
+  QJsonArray array = doc.array();
+  if(array.isEmpty()) {
 //    myDebug() << "no results";
     endJob(job);
     return;
@@ -284,65 +250,69 @@ void OpenLibraryFetcher::slotComplete(KJob* job_) {
     coll->addField(field);
   }
 
-  QVariantMap resultMap;
-  foreach(const QVariant& result, resultList) {
+  for(int i = 0; i < array.count(); i++) {
     // be sure to check that the fetcher has not been stopped
     // crashes can occur if not
     if(!m_started) {
       break;
     }
 //    myDebug() << "found result:" << result;
-    resultMap = result.toMap();
+    QVariantMap resultMap = array.at(i).toObject().toVariantMap();
 
 //  myDebug() << resultMap.value(QLatin1String("isbn_10")).toList().at(0);
 
     Data::EntryPtr entry(new Data::Entry(coll));
 
-    entry->setField(QLatin1String("title"), value(resultMap, "title"));
-    entry->setField(QLatin1String("subtitle"), value(resultMap, "subtitle"));
-    entry->setField(QLatin1String("pub_year"), value(resultMap, "publish_date"));
-    QString isbn = value(resultMap, "isbn_10");
+    entry->setField(QLatin1String("title"), mapValue(resultMap, "title"));
+    entry->setField(QLatin1String("subtitle"), mapValue(resultMap, "subtitle"));
+    entry->setField(QLatin1String("pub_year"), mapValue(resultMap, "publish_date"));
+    QString isbn = mapValue(resultMap, "isbn_10");
     if(isbn.isEmpty()) {
-      isbn = value(resultMap, "isbn_13");
+      isbn = mapValue(resultMap, "isbn_13");
     }
     if(!isbn.isEmpty()) {
       ISBNValidator val(this);
       val.fixup(isbn);
       entry->setField(QLatin1String("isbn"), isbn);
     }
-    entry->setField(QLatin1String("lccn"), value(resultMap, "lccn"));
-    entry->setField(QLatin1String("genre"), value(resultMap, "genres"));
-    entry->setField(QLatin1String("keyword"), value(resultMap, "subjects"));
-    entry->setField(QLatin1String("edition"), value(resultMap, "edition_name"));
-    QString binding = value(resultMap, "physical_format");
+    entry->setField(QLatin1String("lccn"), mapValue(resultMap, "lccn"));
+    entry->setField(QLatin1String("genre"), mapValue(resultMap, "genres"));
+    entry->setField(QLatin1String("keyword"), mapValue(resultMap, "subjects"));
+    entry->setField(QLatin1String("edition"), mapValue(resultMap, "edition_name"));
+    QString binding = mapValue(resultMap, "physical_format");
     if(binding.toLower() == QLatin1String("hardcover")) {
       binding = QLatin1String("Hardback");
-    } else if(binding.toLower().contains(QLatin1String("paperback"))) {
+    } else if(binding.contains(QLatin1String("paperback"), Qt::CaseInsensitive)) {
       binding = QLatin1String("Paperback");
     }
-    entry->setField(QLatin1String("binding"), i18n(binding.toUtf8()));
-    entry->setField(QLatin1String("publisher"), value(resultMap, "publishers"));
-    entry->setField(QLatin1String("series"), value(resultMap, "series"));
-    entry->setField(QLatin1String("pages"), value(resultMap, "number_of_pages"));
-    entry->setField(QLatin1String("comments"), value(resultMap, "notes"));
+    if(!binding.isEmpty()) {
+      entry->setField(QLatin1String("binding"), i18n(binding.toUtf8().constData()));
+    }
+    entry->setField(QLatin1String("publisher"), mapValue(resultMap, "publishers"));
+    entry->setField(QLatin1String("series"), mapValue(resultMap, "series"));
+    entry->setField(QLatin1String("pages"), mapValue(resultMap, "number_of_pages"));
+    entry->setField(QLatin1String("comments"), mapValue(resultMap, "notes"));
 
     if(optionalFields().contains(QLatin1String("openlibrary"))) {
-      entry->setField(QLatin1String("openlibrary"), QLatin1String("http://openlibrary.org") + value(resultMap, "key"));
+      entry->setField(QLatin1String("openlibrary"), QLatin1String("http://openlibrary.org") + mapValue(resultMap, "key"));
     }
 
     QStringList authors;
     foreach(const QVariant& authorMap, resultMap.value(QLatin1String("authors")).toList()) {
-      const QString key = value(authorMap.toMap(), "key");
+      const QString key = mapValue(authorMap.toMap(), "key");
       if(!key.isEmpty()) {
-        KUrl authorUrl(OPENLIBRARY_QUERY_URL);
-        authorUrl.addQueryItem(QLatin1String("type"), QLatin1String("/type/author"));
-        authorUrl.addQueryItem(QLatin1String("key"), key);
-        authorUrl.addQueryItem(QLatin1String("name"), QString());
+        QUrl authorUrl(QString::fromLatin1(OPENLIBRARY_QUERY_URL));
+        QUrlQuery q;
+        q.addQueryItem(QLatin1String("type"), QLatin1String("/type/author"));
+        q.addQueryItem(QLatin1String("key"), key);
+        q.addQueryItem(QLatin1String("name"), QString());
+        authorUrl.setQuery(q);
 
-        QString output = FileHandler::readTextFile(authorUrl, false /*quiet*/);
-        QVariantList authorList = parser.parse(output.toUtf8()).toList();
-        QVariantMap authorResult = authorList.isEmpty() ? QVariantMap() : authorList.at(0).toMap();
-        const QString name = value(authorResult, "name");
+        QString output = FileHandler::readTextFile(authorUrl, true /*quiet*/);
+        QJsonDocument doc = QJsonDocument::fromJson(output.toUtf8());
+        QJsonArray array = doc.array();
+        QVariantMap authorResult = array.isEmpty() ? QVariantMap() : array.at(0).toObject().toVariantMap();
+        const QString name = mapValue(authorResult, "name");
         if(!name.isEmpty()) {
           authors << name;
         }
@@ -354,19 +324,22 @@ void OpenLibraryFetcher::slotComplete(KJob* job_) {
 
     QStringList langs;
     foreach(const QVariant& langMap, resultMap.value(QLatin1String("languages")).toList()) {
-      const QString key = value(langMap.toMap(), "key");
+      const QString key = mapValue(langMap.toMap(), "key");
       if(!key.isEmpty()) {
-        KUrl langUrl(OPENLIBRARY_QUERY_URL);
-        langUrl.addQueryItem(QLatin1String("type"), QLatin1String("/type/language"));
-        langUrl.addQueryItem(QLatin1String("key"), key);
-        langUrl.addQueryItem(QLatin1String("name"), QString());
+        QUrl langUrl(QString::fromLatin1(OPENLIBRARY_QUERY_URL));
+        QUrlQuery q;
+        q.addQueryItem(QLatin1String("type"), QLatin1String("/type/language"));
+        q.addQueryItem(QLatin1String("key"), key);
+        q.addQueryItem(QLatin1String("name"), QString());
+        langUrl.setQuery(q);
 
-        QString output = FileHandler::readTextFile(langUrl, false /*quiet*/, true /*utf8*/);
-        QVariantList langList = parser.parse(output.toUtf8()).toList();
-        QVariantMap langResult = langList.isEmpty() ? QVariantMap() : langList.at(0).toMap();
-        const QString name = value(langResult, "name");
+        QString output = FileHandler::readTextFile(langUrl, true /*quiet*/, true /*utf8*/);
+        QJsonDocument doc = QJsonDocument::fromJson(output.toUtf8());
+        QJsonArray array = doc.array();
+        QVariantMap langResult = array.isEmpty() ? QVariantMap() : array.at(0).toObject().toVariantMap();
+        const QString name = mapValue(langResult, "name");
         if(!name.isEmpty()) {
-          langs << i18n(name.toUtf8());
+          langs << i18n(name.toUtf8().constData());
         }
       }
     }
@@ -382,27 +355,22 @@ void OpenLibraryFetcher::slotComplete(KJob* job_) {
 //  m_start = m_entries.count();
 //  m_hasMoreResults = m_start <= m_total;
   m_hasMoreResults = false; // for now, no continued searches
-#endif
   endJob(job);
 }
 
 QString OpenLibraryFetcher::getAuthorKeys(const QString& term_) {
-#ifdef HAVE_QJSON
-  KUrl u(OPENLIBRARY_QUERY_URL);
+  QUrl u(QString::fromLatin1(OPENLIBRARY_QUERY_URL));
+  QUrlQuery q;
+  q.addQueryItem(QLatin1String("type"), QLatin1String("/type/author"));
+  q.addQueryItem(QLatin1String("name"), term_);
+  u.setQuery(q);
 
-  u.addQueryItem(QLatin1String("type"), QLatin1String("/type/author"));
-  u.addQueryItem(QLatin1String("name"), term_);
-
-  QString output = FileHandler::readTextFile(u, false /*quiet*/, true /*utf8*/);
-  QJson::Parser parser;
-  QVariantList results = parser.parse(output.toUtf8()).toList();
-  myDebug() << "found" << results.count() << "authors";
+  QString output = FileHandler::readTextFile(u, true /*quiet*/, true /*utf8*/);
+  QJsonDocument doc = QJsonDocument::fromJson(output.toUtf8());
+  QJsonArray array = doc.array();
+  myDebug() << "found" << array.count() << "authors";
   // right now, only use the first
-  return results.isEmpty() ? QString() : value(results.at(0).toMap(), "key");
-#else
-  Q_UNUSED(term_);
-  return QString();
-#endif
+  return array.isEmpty() ? QString() : mapValue(array.at(0).toObject().toVariantMap(), "key");
 }
 
 Tellico::Fetch::ConfigWidget* OpenLibraryFetcher::configWidget(QWidget* parent_) const {
@@ -414,7 +382,7 @@ QString OpenLibraryFetcher::defaultName() {
 }
 
 QString OpenLibraryFetcher::defaultIcon() {
-  return favIcon("http://www.openlibrary.org");
+  return favIcon("http://openlibrary.org");
 }
 
 Tellico::StringHash OpenLibraryFetcher::allOptionalFields() {
@@ -439,21 +407,3 @@ void OpenLibraryFetcher::ConfigWidget::saveConfigHook(KConfigGroup&) {
 QString OpenLibraryFetcher::ConfigWidget::preferredName() const {
   return OpenLibraryFetcher::defaultName();
 }
-
-// static
-QString OpenLibraryFetcher::value(const QVariantMap& map, const char* name) {
-  const QVariant v = map.value(QLatin1String(name));
-  if(v.isNull())  {
-    return QString();
-  } else if(v.canConvert(QVariant::String)) {
-    return v.toString();
-  } else if(v.canConvert(QVariant::StringList)) {
-    return v.toStringList().join(Tellico::FieldFormat::delimiterString());
-  } else if(v.canConvert(QVariant::Map)) {
-    return v.toMap().value(QLatin1String("value")).toString();
-  } else {
-    return QString();
-  }
-}
-
-#include "openlibraryfetcher.moc"
