@@ -294,6 +294,7 @@ void TheMovieDBFetcher::slotComplete(KJob* job_) {
     return;
   }
 
+  int count = 0;
   foreach(const QVariant& result, resultList) {
 //    myDebug() << "found result:" << result;
 
@@ -303,6 +304,10 @@ void TheMovieDBFetcher::slotComplete(KJob* job_) {
     FetchResult* r = new FetchResult(Fetcher::Ptr(this), entry);
     m_entries.insert(r->uid, entry);
     emit signalResultFound(r);
+    ++count;
+    if(count >= THEMOVIEDB_MAX_RETURNS_TOTAL) {
+      break;
+    }
   }
 
   stop();
