@@ -46,24 +46,24 @@
 #include "../gui/combobox.h"
 #include "../utils/isbnvalidator.h"
 #include "../utils/lccnvalidator.h"
+#include "../utils/datafileregistry.h"
 #include "../tellico_debug.h"
 
-#include <klocale.h>
-#include <kstandarddirs.h>
-#include <kapplication.h>
-#include <knuminput.h>
+#include <KLocalizedString>
 #include <KConfigGroup>
-#include <kcombobox.h>
-#include <kacceleratormanager.h>
-#include <kseparator.h>
-#include <KIcon>
+#include <KComboBox>
+#include <KAcceleratorManager>
+#include <KSeparator>
+#include <KConfig>
 
+#include <QSpinBox>
 #include <QFile>
 #include <QLabel>
 #include <QDomDocument>
 #include <QTextStream>
 #include <QTextCodec>
 #include <QGridLayout>
+#include <QIcon>
 
 namespace {
   static const int Z3950_DEFAULT_PORT = 210;
@@ -74,22 +74,21 @@ using namespace Tellico;
 using Tellico::Fetch::Z3950Fetcher;
 
 Z3950Fetcher::Z3950Fetcher(QObject* parent_)
-    : Fetcher(parent_), m_conn(0), m_port(Z3950_DEFAULT_PORT), m_esn(Z3950_DEFAULT_ESN),
-      m_started(false), m_done(true), m_MARC21XMLHandler(0),
-      m_UNIMARCXMLHandler(0), m_MODSHandler(0) {
+    : Fetcher(parent_), m_conn(nullptr), m_port(Z3950_DEFAULT_PORT), m_esn(Z3950_DEFAULT_ESN),
+      m_started(false), m_done(true), m_MARC21XMLHandler(nullptr),
+      m_UNIMARCXMLHandler(nullptr), m_MODSHandler(nullptr) {
 }
 
 Z3950Fetcher::Z3950Fetcher(QObject* parent_, const QString& preset_)
-    : Fetcher(parent_), m_conn(0), m_started(false), m_done(true), m_preset(preset_),
-      m_MARC21XMLHandler(0), m_UNIMARCXMLHandler(0), m_MODSHandler(0) {
-  QString serverFile = KStandardDirs::locate("appdata", QLatin1String("z3950-servers.cfg"));
+    : Fetcher(parent_), m_conn(nullptr), m_port(Z3950_DEFAULT_PORT), m_started(false), m_done(true), m_preset(preset_),
+      m_MARC21XMLHandler(nullptr), m_UNIMARCXMLHandler(nullptr), m_MODSHandler(nullptr) {
+  QString serverFile = DataFileRegistry::self()->locate(QLatin1String("z3950-servers.cfg"));
   if(!serverFile.isEmpty()) {
     KConfig serverConfig(serverFile, KConfig::SimpleConfig);
     const QStringList servers = serverConfig.groupList();
     for(QStringList::ConstIterator server = servers.begin(); server != servers.end(); ++server) {
       if(*server == m_preset) {
         KConfigGroup cfg(&serverConfig, *server);
-        const QString name = cfg.readEntry("Name");
         m_host = cfg.readEntry("Host");
         m_port = cfg.readEntry("Port", Z3950_DEFAULT_PORT);
         m_dbname = cfg.readEntry("Database");
@@ -106,24 +105,24 @@ Z3950Fetcher::Z3950Fetcher(QObject* parent_, const QString& preset_)
 
 Z3950Fetcher::Z3950Fetcher(QObject* parent_, const QString& host_, int port_,
                            const QString& dbName_, const QString& syntax_)
-    : Fetcher(parent_), m_conn(0), m_host(host_), m_port(port_), m_dbname(dbName_)
+    : Fetcher(parent_), m_conn(nullptr), m_host(host_), m_port(port_), m_dbname(dbName_)
     , m_syntax(syntax_), m_esn(Z3950_DEFAULT_ESN)
-    , m_started(false), m_done(true), m_MARC21XMLHandler(0)
-    , m_UNIMARCXMLHandler(0), m_MODSHandler(0) {
+    , m_started(false), m_done(true), m_MARC21XMLHandler(nullptr)
+    , m_UNIMARCXMLHandler(nullptr), m_MODSHandler(nullptr) {
 }
 
 Z3950Fetcher::~Z3950Fetcher() {
   delete m_MARC21XMLHandler;
-  m_MARC21XMLHandler = 0;
+  m_MARC21XMLHandler = nullptr;
   delete m_UNIMARCXMLHandler;
-  m_UNIMARCXMLHandler = 0;
+  m_UNIMARCXMLHandler = nullptr;
   delete m_MODSHandler;
-  m_MODSHandler = 0;
+  m_MODSHandler = nullptr;
 
   if(m_conn) {
     m_conn->wait();
     m_conn->deleteLater();
-    m_conn = 0;
+    m_conn = nullptr;
   }
 }
 
@@ -150,14 +149,14 @@ void Z3950Fetcher::readConfigHook(const KConfigGroup& config_) {
     m_password = config_.readEntry("Password");
   } else {
     m_preset = preset;
-    QString serverFile = KStandardDirs::locate("appdata", QLatin1String("z3950-servers.cfg"));
+    QString serverFile = DataFileRegistry::self()->locate(QLatin1String("z3950-servers.cfg"));
     if(!serverFile.isEmpty()) {
       KConfig serverConfig(serverFile, KConfig::SimpleConfig);
       const QStringList servers = serverConfig.groupList();
       for(QStringList::ConstIterator server = servers.begin(); server != servers.end(); ++server) {
         if(*server == preset) {
           KConfigGroup cfg(&serverConfig, *server);
-          const QString name = cfg.readEntry("Name");
+//          const QString name = cfg.readEntry("Name");
           m_host = cfg.readEntry("Host");
           m_port = cfg.readEntry("Port", Z3950_DEFAULT_PORT);
           m_dbname = cfg.readEntry("Database");
@@ -297,20 +296,19 @@ bool Z3950Fetcher::initMARC21Handler() {
     return true;
   }
 
-  QString xsltfile = KStandardDirs::locate("appdata", QLatin1String("MARC21slim2MODS3.xsl"));
+  QString xsltfile = DataFileRegistry::self()->locate(QLatin1String("MARC21slim2MODS3.xsl"));
   if(xsltfile.isEmpty()) {
     myWarning() << "can not locate MARC21slim2MODS3.xsl.";
     return false;
   }
 
-  KUrl u;
-  u.setPath(xsltfile);
+  QUrl u = QUrl::fromLocalFile(xsltfile);
 
   m_MARC21XMLHandler = new XSLTHandler(u);
   if(!m_MARC21XMLHandler->isValid()) {
     myWarning() << "error in MARC21slim2MODS3.xsl.";
     delete m_MARC21XMLHandler;
-    m_MARC21XMLHandler = 0;
+    m_MARC21XMLHandler = nullptr;
     return false;
   }
   return true;
@@ -321,20 +319,19 @@ bool Z3950Fetcher::initUNIMARCHandler() {
     return true;
   }
 
-  QString xsltfile = KStandardDirs::locate("appdata", QLatin1String("UNIMARC2MODS3.xsl"));
+  QString xsltfile = DataFileRegistry::self()->locate(QLatin1String("UNIMARC2MODS3.xsl"));
   if(xsltfile.isEmpty()) {
     myWarning() << "can not locate UNIMARC2MODS3.xsl.";
     return false;
   }
 
-  KUrl u;
-  u.setPath(xsltfile);
+  QUrl u = QUrl::fromLocalFile(xsltfile);
 
   m_UNIMARCXMLHandler = new XSLTHandler(u);
   if(!m_UNIMARCXMLHandler->isValid()) {
     myWarning() << "error in UNIMARC2MODS3.xsl.";
     delete m_UNIMARCXMLHandler;
-    m_UNIMARCXMLHandler = 0;
+    m_UNIMARCXMLHandler = nullptr;
     return false;
   }
   return true;
@@ -345,25 +342,24 @@ bool Z3950Fetcher::initMODSHandler() {
     return true;
   }
 
-  QString xsltfile = KStandardDirs::locate("appdata", QLatin1String("mods2tellico.xsl"));
+  QString xsltfile = DataFileRegistry::self()->locate(QLatin1String("mods2tellico.xsl"));
   if(xsltfile.isEmpty()) {
     myWarning() << "can not locate mods2tellico.xsl.";
     return false;
   }
 
-  KUrl u;
-  u.setPath(xsltfile);
+  QUrl u = QUrl::fromLocalFile(xsltfile);
 
   m_MODSHandler = new XSLTHandler(u);
   if(!m_MODSHandler->isValid()) {
     myWarning() << "error in mods2tellico.xsl.";
     delete m_MODSHandler;
-    m_MODSHandler = 0;
+    m_MODSHandler = nullptr;
     // no use in keeping the MARC handlers now
     delete m_MARC21XMLHandler;
-    m_MARC21XMLHandler = 0;
+    m_MARC21XMLHandler = nullptr;
     delete m_UNIMARCXMLHandler;
-    m_UNIMARCXMLHandler = 0;
+    m_UNIMARCXMLHandler = nullptr;
     return false;
   }
   return true;
@@ -556,7 +552,8 @@ QString Z3950Fetcher::defaultName() {
 }
 
 QString Z3950Fetcher::defaultIcon() {
-  return QLatin1String("network-wired"); // rather arbitrary
+//  return QLatin1String("network-server"); // rather arbitrary
+  return QLatin1String("network-server-database"); // rather arbitrary
 }
 
 // static
@@ -601,7 +598,10 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const Z3950Fetcher* f
 
   label = new QLabel(i18n("&Port: "), optionsWidget());
   l->addWidget(label, ++row, 0);
-  m_portSpinBox = new KIntSpinBox(0, 999999, 1, Z3950_DEFAULT_PORT, optionsWidget());
+  m_portSpinBox = new QSpinBox(optionsWidget());
+  m_portSpinBox->setMaximum(999999);
+  m_portSpinBox->setMinimum(0);
+  m_portSpinBox->setValue(Z3950_DEFAULT_PORT);
   connect(m_portSpinBox, SIGNAL(valueChanged(int)), SLOT(slotSetModified()));
   l->addWidget(m_portSpinBox, row, 1);
   w = i18n("Enter the port number of the server. The default is %1.", Z3950_DEFAULT_PORT);
@@ -626,7 +626,7 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const Z3950Fetcher* f
   m_charSetCombo->addItem(QLatin1String("marc8"));
   m_charSetCombo->addItem(QLatin1String("iso-8859-1"));
   m_charSetCombo->addItem(QLatin1String("utf-8"));
-  connect(m_charSetCombo, SIGNAL(textChanged(const QString&)), SLOT(slotSetModified()));
+  connect(m_charSetCombo, SIGNAL(currentTextChanged(const QString&)), SLOT(slotSetModified()));
   l->addWidget(m_charSetCombo, row, 1);
   w = i18n("Enter the character set encoding used by the z39.50 server. The most likely choice "
            "is MARC-8, although ISO-8859-1 is common as well.");
@@ -644,7 +644,7 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const Z3950Fetcher* f
   m_syntaxCombo->addItem(QLatin1String("USMARC"), QLatin1String("usmarc"));
   m_syntaxCombo->addItem(QLatin1String("ADS"), QLatin1String("ads"));
   m_syntaxCombo->addItem(QLatin1String("GRS-1"), QLatin1String("grs-1"));
-  connect(m_syntaxCombo, SIGNAL(textChanged(const QString&)), SLOT(slotSetModified()));
+  connect(m_syntaxCombo, SIGNAL(currentTextChanged(const QString&)), SLOT(slotSetModified()));
   l->addWidget(m_syntaxCombo, row, 1);
   w = i18n("Enter the data format used by the z39.50 server. Tellico will attempt to "
            "automatically detect the best setting if <i>auto-detect</i> is selected.");
@@ -655,7 +655,7 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const Z3950Fetcher* f
   label = new QLabel(i18n("&User: "), optionsWidget());
   l->addWidget(label, ++row, 0);
   m_userEdit = new GUI::LineEdit(optionsWidget());
-  m_userEdit->setClickMessage(i18n("Optional"));
+  m_userEdit->setPlaceholderText(i18n("Optional"));
   connect(m_userEdit, SIGNAL(textChanged(const QString&)), SLOT(slotSetModified()));
   l->addWidget(m_userEdit, row, 1);
   w = i18n("Enter the authentication user name used by the z39.50 database. Most servers "
@@ -667,7 +667,7 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const Z3950Fetcher* f
   label = new QLabel(i18n("Pass&word: "), optionsWidget());
   l->addWidget(label, ++row, 0);
   m_passwordEdit = new GUI::LineEdit(optionsWidget());
-  m_passwordEdit->setClickMessage(i18n("Optional"));
+  m_passwordEdit->setPlaceholderText(i18n("Optional"));
   m_passwordEdit->setEchoMode(QLineEdit::Password);
   connect(m_passwordEdit, SIGNAL(textChanged(const QString&)), SLOT(slotSetModified()));
   l->addWidget(m_passwordEdit, row, 1);
@@ -772,14 +772,10 @@ void Z3950Fetcher::ConfigWidget::slotPresetChanged() {
 }
 
 void Z3950Fetcher::ConfigWidget::loadPresets(const QString& current_) {
-  QString lang = KGlobal::locale()->languageList().first();
-  QString lang2A;
-  {
-    QString dummy;
-    KGlobal::locale()->splitLocale(lang, lang2A, dummy, dummy, dummy);
-  }
+  const QString lang = QLocale().uiLanguages().constFirst();
+  const QString lang2A = lang.contains(QLatin1Char('-')) ? lang.section(QLatin1Char('-'), 0, 0) : lang;
 
-  QString serverFile = KStandardDirs::locate("appdata", QLatin1String("z3950-servers.cfg"));
+  QString serverFile = DataFileRegistry::self()->locate(QLatin1String("z3950-servers.cfg"));
   if(serverFile.isEmpty()) {
     myWarning() << "no z3950 servers file found";
     return;
@@ -791,6 +787,7 @@ void Z3950Fetcher::ConfigWidget::loadPresets(const QString& current_) {
   const QStringList servers = serverConfig.groupList();
   // I want the list of servers sorted by name so use QMap instead of QHash
   QMap<QString, QString> serverNameMap;
+  QHash<QString, QIcon> flags;
   for(QStringList::ConstIterator server = servers.constBegin(); server != servers.constEnd(); ++server) {
     if((*server).isEmpty()) {
       myDebug() << "empty id";
@@ -808,13 +805,21 @@ void Z3950Fetcher::ConfigWidget::loadPresets(const QString& current_) {
     KConfigGroup cfg(&serverConfig, group);
     const QString country = cfg.readEntry("Country", QString());
 
-    if(country.isEmpty()) {
-      m_serverCombo->addItem(i18n(name.toUtf8()), group);
-    } else {
-      const QString flag = KStandardDirs::locate("locale",
-                                                 QString::fromLatin1("l10n/%1/flag.png").arg(country));
-      m_serverCombo->addItem(KIcon(flag), i18n(name.toUtf8()), group);
+    QIcon icon;
+    if(!country.isEmpty()) {
+      QHash<QString, QIcon>::ConstIterator it = flags.constFind(country);
+      if(it != flags.constEnd()) {
+        icon = it.value();
+      } else {
+        const QString flag = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
+                                                    QString::fromLatin1("kf5/locale/countries/%1/flag.png").arg(country));
+        if (!flag.isEmpty()) {
+          icon = QIcon(flag);
+          flags.insert(country, icon);
+        }
+      }
     }
+    m_serverCombo->addItem(icon, name, group);
 
     if(current_.isEmpty() && idx == -1) {
       // set the initial selection to something depending on the language
@@ -838,5 +843,3 @@ QString Z3950Fetcher::ConfigWidget::preferredName() const {
   QString s = m_hostEdit->text();
   return s.isEmpty() ? i18n("z39.50 Server") : s;
 }
-
-#include "z3950fetcher.moc"
